require_relative "cipher_encrypt"
require_relative "key"
require_relative "offset"

module Gemnigma
  class RotatorEncrypt
    attr_reader :key_map
    
    def initialize(key = Gemnigma::Key.new)

      if key.methods.include? :key_map
        @key_map = key.key_map
      else
        puts "Invalid key, using default key: 41521"
        @key_map = Gemnigma::Key.new.key_map
      end

    end

    def rot_encrypt(word)
      mapping = map_word_to_key(word)
      
      mapping.map! do |arr|
        Gemnigma::CipherEncrypt.rotate_forward(arr.last)[arr.first]
      end

      mapping.join
    end

    private

    def get_offset
      Gemnigma::Offset.new.offset
    end

    def map_key_to_offset
      @key_map.zip(get_offset)
    end

    def char_rotation
      map_key_to_offset.map do |arr|
        arr.inject(&:+)
      end
    end

    def map_word_to_key(word)
      result = []
      count_key = 0

      word.downcase.split("").each_with_index do |letter, index|
        if count_key >= char_rotation.length
          count_key = 0
        end
        result << [letter, char_rotation[count_key]]
        count_key += 1
      end

      result
    end

  end
end